# This file was auto-generated by Fern from our API Definition.

import typing

from ....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ....core.request_options import RequestOptions
from ....types.project_member_bulk_assign_roles_request import ProjectMemberBulkAssignRolesRequest
from .raw_client import AsyncRawBulkClient, RawBulkClient
from .types.delete_bulk_response import DeleteBulkResponse
from .types.post_bulk_response import PostBulkResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class BulkClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawBulkClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawBulkClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawBulkClient
        """
        return self._raw_client

    def post(
        self,
        id: int,
        *,
        all_: bool,
        last_activity_gte: typing.Optional[str] = None,
        last_activity_lte: typing.Optional[str] = None,
        role: typing.Optional[str] = None,
        search: typing.Optional[str] = None,
        tags: typing.Optional[str] = None,
        excluded: typing.Optional[typing.Sequence[int]] = OMIT,
        included: typing.Optional[typing.Sequence[int]] = OMIT,
        roles: typing.Optional[typing.Sequence[ProjectMemberBulkAssignRolesRequest]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PostBulkResponse:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Assign project members in bulk.

        Parameters
        ----------
        id : int

        all_ : bool

        last_activity_gte : typing.Optional[str]
            Filter by last activity (ISO 8601 formatted date). Only when all=True.

        last_activity_lte : typing.Optional[str]
            Filter by last activity upper bound (ISO 8601 formatted date). Only when all=True.

        role : typing.Optional[str]
            Filter by role, project roles take precedence over organization roles. Only when all=True. (comma-separated values)

        search : typing.Optional[str]
            Search term for filtering members by name, email, or username. Only when all=True.

        tags : typing.Optional[str]
            Filter tags by in list (comma-separated values)

        excluded : typing.Optional[typing.Sequence[int]]

        included : typing.Optional[typing.Sequence[int]]

        roles : typing.Optional[typing.Sequence[ProjectMemberBulkAssignRolesRequest]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PostBulkResponse


        Examples
        --------
        from label_studio_sdk import LabelStudio

        client = LabelStudio(
            api_key="YOUR_API_KEY",
        )
        client.projects.members.bulk.post(
            id=1,
            all_=True,
        )
        """
        _response = self._raw_client.post(
            id,
            all_=all_,
            last_activity_gte=last_activity_gte,
            last_activity_lte=last_activity_lte,
            role=role,
            search=search,
            tags=tags,
            excluded=excluded,
            included=included,
            roles=roles,
            request_options=request_options,
        )
        return _response.data

    def delete(
        self,
        id: int,
        *,
        last_activity_gte: typing.Optional[str] = None,
        last_activity_lte: typing.Optional[str] = None,
        role: typing.Optional[str] = None,
        search: typing.Optional[str] = None,
        tags: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> DeleteBulkResponse:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Unassign project members in bulk. Allows the same request body as bulk assign.

        Parameters
        ----------
        id : int

        last_activity_gte : typing.Optional[str]
            Filter by last activity (ISO 8601 formatted date). Only when all=True.

        last_activity_lte : typing.Optional[str]
            Filter by last activity upper bound (ISO 8601 formatted date). Only when all=True.

        role : typing.Optional[str]
            Filter by role, project roles take precedence over organization roles. Only when all=True. (comma-separated values)

        search : typing.Optional[str]
            Search term for filtering members by name, email, or username. Only when all=True.

        tags : typing.Optional[str]
            Filter tags by in list (comma-separated values)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteBulkResponse


        Examples
        --------
        from label_studio_sdk import LabelStudio

        client = LabelStudio(
            api_key="YOUR_API_KEY",
        )
        client.projects.members.bulk.delete(
            id=1,
        )
        """
        _response = self._raw_client.delete(
            id,
            last_activity_gte=last_activity_gte,
            last_activity_lte=last_activity_lte,
            role=role,
            search=search,
            tags=tags,
            request_options=request_options,
        )
        return _response.data


class AsyncBulkClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawBulkClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawBulkClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawBulkClient
        """
        return self._raw_client

    async def post(
        self,
        id: int,
        *,
        all_: bool,
        last_activity_gte: typing.Optional[str] = None,
        last_activity_lte: typing.Optional[str] = None,
        role: typing.Optional[str] = None,
        search: typing.Optional[str] = None,
        tags: typing.Optional[str] = None,
        excluded: typing.Optional[typing.Sequence[int]] = OMIT,
        included: typing.Optional[typing.Sequence[int]] = OMIT,
        roles: typing.Optional[typing.Sequence[ProjectMemberBulkAssignRolesRequest]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PostBulkResponse:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Assign project members in bulk.

        Parameters
        ----------
        id : int

        all_ : bool

        last_activity_gte : typing.Optional[str]
            Filter by last activity (ISO 8601 formatted date). Only when all=True.

        last_activity_lte : typing.Optional[str]
            Filter by last activity upper bound (ISO 8601 formatted date). Only when all=True.

        role : typing.Optional[str]
            Filter by role, project roles take precedence over organization roles. Only when all=True. (comma-separated values)

        search : typing.Optional[str]
            Search term for filtering members by name, email, or username. Only when all=True.

        tags : typing.Optional[str]
            Filter tags by in list (comma-separated values)

        excluded : typing.Optional[typing.Sequence[int]]

        included : typing.Optional[typing.Sequence[int]]

        roles : typing.Optional[typing.Sequence[ProjectMemberBulkAssignRolesRequest]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PostBulkResponse


        Examples
        --------
        import asyncio

        from label_studio_sdk import AsyncLabelStudio

        client = AsyncLabelStudio(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.projects.members.bulk.post(
                id=1,
                all_=True,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.post(
            id,
            all_=all_,
            last_activity_gte=last_activity_gte,
            last_activity_lte=last_activity_lte,
            role=role,
            search=search,
            tags=tags,
            excluded=excluded,
            included=included,
            roles=roles,
            request_options=request_options,
        )
        return _response.data

    async def delete(
        self,
        id: int,
        *,
        last_activity_gte: typing.Optional[str] = None,
        last_activity_lte: typing.Optional[str] = None,
        role: typing.Optional[str] = None,
        search: typing.Optional[str] = None,
        tags: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> DeleteBulkResponse:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Unassign project members in bulk. Allows the same request body as bulk assign.

        Parameters
        ----------
        id : int

        last_activity_gte : typing.Optional[str]
            Filter by last activity (ISO 8601 formatted date). Only when all=True.

        last_activity_lte : typing.Optional[str]
            Filter by last activity upper bound (ISO 8601 formatted date). Only when all=True.

        role : typing.Optional[str]
            Filter by role, project roles take precedence over organization roles. Only when all=True. (comma-separated values)

        search : typing.Optional[str]
            Search term for filtering members by name, email, or username. Only when all=True.

        tags : typing.Optional[str]
            Filter tags by in list (comma-separated values)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteBulkResponse


        Examples
        --------
        import asyncio

        from label_studio_sdk import AsyncLabelStudio

        client = AsyncLabelStudio(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.projects.members.bulk.delete(
                id=1,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(
            id,
            last_activity_gte=last_activity_gte,
            last_activity_lte=last_activity_lte,
            role=role,
            search=search,
            tags=tags,
            request_options=request_options,
        )
        return _response.data
